@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 from django.apps import AppConfig
 
 
 class MoneyConfig(AppConfig):
-    name = 'djmoney'
+    name = "djmoney"
 
     def ready(self):
         try:
