@@ -1,55 +1,49 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-from warnings import warn
-
 from django.core.exceptions import ValidationError
 from django.forms import ChoiceField, DecimalField, MultiValueField
 
-from moneyed.classes import Money
+from djmoney.money import Money
+from djmoney.utils import MONEY_CLASSES
 
-from ..settings import CURRENCY_CHOICES
+from ..settings import CURRENCY_CHOICES, DECIMAL_PLACES
 from .widgets import MoneyWidget
 
 
-__all__ = ('MoneyField',)
+__all__ = ("MoneyField",)
 
 
 class MoneyField(MultiValueField):
+    def __init__(
+        self,
+        currency_widget=None,
+        currency_choices=CURRENCY_CHOICES,
+        max_value=None,
+        min_value=None,
+        max_digits=None,
+        decimal_places=DECIMAL_PLACES,
+        default_amount=None,
+        default_currency=None,
+        *args,
+        **kwargs
+    ):
 
-    def __init__(self, currency_widget=None, currency_choices=CURRENCY_CHOICES,
-                 choices=CURRENCY_CHOICES, max_value=None, min_value=None,
-                 max_digits=None, decimal_places=None, default_amount=None,
-                 *args, **kwargs):
+        amount_field = DecimalField(
+            *args,
+            max_value=max_value,
+            min_value=min_value,
+            max_digits=max_digits,
+            decimal_places=decimal_places,
+            **kwargs
+        )
+        currency_field = ChoiceField(choices=currency_choices)
 
-        # choices does not make sense in this context, it would mean we had
-        # to replace two widgets with one widget dynamically... which is a
-        # mess. Instead, we let currency_choices be the same as choices and
-        # raise a warning.
-        if currency_choices != CURRENCY_CHOICES:
-            warn('currency_choices will be deprecated in favor of choices', PendingDeprecationWarning)
-            choices = currency_choices
-
-        # get the default currency if one was specified
-        default_currency = kwargs.pop('default_currency', None)
-
-        amount_field = DecimalField(max_value, min_value, max_digits, decimal_places, *args, **kwargs)
-        currency_field = ChoiceField(choices=choices)
-
-        # TODO: No idea what currency_widget is supposed to do since it doesn't
-        # even receive currency choices as input. Somehow it's supposed to be
-        # instantiated from outside. Hard to tell.
-        if currency_widget:
-            self.widget = currency_widget
-        else:
-            self.widget = MoneyWidget(
-                amount_widget=amount_field.widget,
-                currency_widget=currency_field.widget,
-                default_currency=default_currency
-            )
+        self.widget = MoneyWidget(
+            amount_widget=amount_field.widget,
+            currency_widget=currency_widget or currency_field.widget,
+            default_currency=default_currency,
+        )
         # The two fields that this widget comprises
         fields = (amount_field, currency_field)
-        super(MoneyField, self).__init__(fields, *args, **kwargs)
+        super().__init__(fields, *args, **kwargs)
 
         # set the initial value to the default currency so that the
         # default currency appears as the selected menu item
@@ -63,9 +57,16 @@ class MoneyField(MultiValueField):
                 return Money(*data_list[:2])
         return None
 
+    def clean(self, value):
+        if isinstance(value, MONEY_CLASSES):
+            value = (value.amount, value.currency)
+        return super().clean(value)
+
     def has_changed(self, initial, data):  # noqa
+        if self.disabled:
+            return False
         if initial is None:
-            initial = ['' for _ in range(0, len(data))]
+            initial = ["" for _ in range(0, len(data))]
         else:
             if not isinstance(initial, list):
                 initial = self.widget.decompress(initial)
